==> haskell-crypto-api-0.13.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.3
id: crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
key: crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
abi: 04b47272348e9aa5648e546d18028ecd
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-0.13.3
hs-libraries: HScrypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=bbba9b47b66235cbe49005ce0f2ca1a5
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.3
id: crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
key: crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
abi: b38ee8fa4c1e132a024035423192fcff
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Classes.Exceptions Crypto.HMAC Crypto.Modes
    Crypto.Padding Crypto.Random Crypto.Types Crypto.Util
hidden-modules: Crypto.CPoly
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-0.13.3
hs-libraries: HScrypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl=f8adc9fd931aa49b6a2a7e2785fb0c69
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
